================================
Russound RIO Async Python Module
================================
.. image:: https://travis-ci.org/wickerwaka/russound_rio.svg?branch=master
    :target: https://travis-ci.org/wickerwaka/russound_rio

This module implements a Python client for the Russound I/O (RIO) protocol used to control Russound audio controllers. RIO supports a superset of the RNET feature set, allows for push notifications of system changes and supports TCP/IP and RS232 communication.
